@@ -1,4 +1,4 @@
-/* $Id: videodev.h 5255 2016-03-10 05:02:07Z ming $ */
+/* $Id$ */
 /*
  * Copyright (C) 2008-2011 Teluu Inc. (http://www.teluu.com)
  *
@@ -25,7 +25,6 @@
  */
 #include <pjmedia-videodev/config.h>
 #include <pjmedia-videodev/errno.h>
-#include <pjmedia/event.h>
 #include <pjmedia/frame.h>
 #include <pjmedia/format.h>
 #include <pj/pool.h>
@@ -163,6 +162,30 @@ enum pjmedia_vid_dev_std_index
 };
 
 
+/**
+ * Enumeration of window fullscreen flags.
+ */
+typedef enum pjmedia_vid_dev_fullscreen_flag
+{
+    /**
+     * Windowed or disable fullscreen.
+     */
+    PJMEDIA_VID_DEV_WINDOWED = 0,
+
+    /**
+     * Fullscreen enabled, video mode may be changed.
+     */
+    PJMEDIA_VID_DEV_FULLSCREEN = 1,
+
+    /**
+     * Fullscreen enabled by resizing video frame to match to the desktop,
+     * video mode will not be changed.
+     */
+    PJMEDIA_VID_DEV_FULLSCREEN_DESKTOP = 2
+
+} pjmedia_vid_dev_fullscreen_flag;
+
+
 /**
  * This enumeration identifies various video device capabilities. These video
  * capabilities indicates what features are supported by the underlying
@@ -275,6 +298,11 @@ typedef enum pjmedia_vid_dev_cap
      */
     PJMEDIA_VID_DEV_CAP_OUTPUT_WINDOW_FLAGS = 512,
 
+    /**
+     * Support for setting the output video window full screen.
+     */
+    PJMEDIA_VID_DEV_CAP_OUTPUT_FULLSCREEN = 1024,
+
     /**
      * End of standard capability
      */
@@ -464,6 +492,13 @@ typedef struct pjmedia_vid_dev_param
      */
     unsigned window_flags;
 
+    /**
+     * Video window's fullscreen status. This setting is optional, and will
+     * only be used if PJMEDIA_VID_DEV_CAP_OUTPUT_FULLSCREEN is set in the
+     * flags.
+     */
+    pjmedia_vid_dev_fullscreen_flag window_fullscreen;
+
 } pjmedia_vid_dev_param;
 
 
