@@ -1,4 +1,4 @@
-/* $Id: sip_config.h 6002 2019-05-23 17:21:59Z riza $ */
+/* $Id$ */
 /* 
  * Copyright (C) 2008-2011 Teluu Inc. (http://www.teluu.com)
  * Copyright (C) 2003-2008 Benny Prijono <benny@prijono.org>
@@ -181,6 +181,14 @@ typedef struct pjsip_cfg_t
          */
         pj_bool_t accept_multiple_sdp_answers;
 
+	/**
+	 * Don't disconnect the INVITE session after an outgoing request
+	 * gets timed out or responded with 408 (request timeout).
+	 *
+	 * Default is PJ_FALSE.
+	 */
+	pj_bool_t keep_inv_after_tsx_timeout;
+
     } endpt;
 
     /** Transaction layer settings. */
@@ -208,6 +216,9 @@ typedef struct pjsip_cfg_t
 
 	/** Transaction completed timer for INVITE, in msec. Default value is
 	 *  PJSIP_TD_TIMEOUT.
+	 *
+	 *  This setting is also used for transaction timeout timer for both
+	 *  INVITE and non-INVITE.
 	 */
 	unsigned td;
 
@@ -894,9 +905,17 @@ PJ_INLINE(pjsip_cfg_t*) pjsip_cfg(void)
 #endif
 
 
-/* Endpoint. */
-#define PJSIP_MAX_TIMER_COUNT		(2*pjsip_cfg()->tsx.max_count + \
+/**
+ * Specify the maximum number of timer entries initially allocated by
+ * endpoint. If the application registers more entries during runtime,
+ * then the timer will automatically resize.
+ *
+ * Default: (2*pjsip_cfg()->tsx.max_count) + (2*PJSIP_MAX_DIALOG_COUNT)
+ */
+#ifndef PJSIP_MAX_TIMER_COUNT
+#   define PJSIP_MAX_TIMER_COUNT	(2*pjsip_cfg()->tsx.max_count + \
 					 2*PJSIP_MAX_DIALOG_COUNT)
+#endif
 
 /**
  * Initial memory block for the endpoint.
@@ -929,8 +948,19 @@ PJ_INLINE(pjsip_cfg_t*) pjsip_cfg(void)
 #   define PJSIP_POOL_RDATA_INC		4000
 #endif
 
-#define PJSIP_POOL_LEN_TRANSPORT	512
-#define PJSIP_POOL_INC_TRANSPORT	512
+/**
+ * Initial memory block for SIP transport.
+ */
+#ifndef PJSIP_POOL_LEN_TRANSPORT
+#   define PJSIP_POOL_LEN_TRANSPORT	512
+#endif
+
+/**
+ * Memory increment for SIP transport.
+ */
+#ifndef PJSIP_POOL_INC_TRANSPORT
+#   define PJSIP_POOL_INC_TRANSPORT	512
+#endif
 
 /**
  * Initial memory block size for tdata.
@@ -960,6 +990,21 @@ PJ_INLINE(pjsip_cfg_t*) pjsip_cfg(void)
 #   define PJSIP_POOL_INC_UA		512
 #endif
 
+/**
+ * Initial memory block for event subscription module.
+ */
+#ifndef PJSIP_POOL_EVSUB_LEN
+#   define PJSIP_POOL_EVSUB_LEN		512
+#endif
+
+/**
+ * Memory increment for event subscription module.
+ */
+#ifndef PJSIP_POOL_EVSUB_INC
+#   define PJSIP_POOL_EVSUB_INC		512
+#endif
+
+
 #define PJSIP_MAX_FORWARDS_VALUE	70
 
 #define PJSIP_RFC3261_BRANCH_ID		"z9hG4bK"
@@ -1011,6 +1056,19 @@ PJ_INLINE(pjsip_cfg_t*) pjsip_cfg(void)
 #   define PJSIP_TSX_1XX_RETRANS_DELAY	60
 #endif
 
+/**
+ * Setting to determine if certain SIP UAS transaction, such as
+ * INVITE UAS tsx that hasn't been confirmed, is allowed to continue
+ * upon transport error. If disabled, the transaction will always be
+ * terminated, which is the default behavior prior to the introduction
+ * of this setting.
+ *
+ * Default: 1 (transaction will continue)
+ */
+#ifndef PJSIP_TSX_UAS_CONTINUE_ON_TP_ERROR
+#   define PJSIP_TSX_UAS_CONTINUE_ON_TP_ERROR 1
+#endif
+
 #define PJSIP_MAX_TSX_KEY_LEN		(PJSIP_MAX_URL_SIZE*2)
 
 /* User agent. */
@@ -1052,7 +1110,12 @@ PJ_INLINE(pjsip_cfg_t*) pjsip_cfg(void)
 #  define PJSIP_T4_TIMEOUT	5000
 #endif
 
-/** Transaction completed timer for INVITE */
+/**
+ * Transaction completed timer for INVITE.
+ *
+ * This setting is also used for transaction timeout timer for both
+ * INVITE and non-INVITE.
+ */
 #if !defined(PJSIP_TD_TIMEOUT)
 #  define PJSIP_TD_TIMEOUT	32000
 #endif
@@ -1179,6 +1242,19 @@ PJ_INLINE(pjsip_cfg_t*) pjsip_cfg(void)
 #   define PJSIP_REGISTER_CLIENT_ADD_XUID_PARAM	0
 #endif
 
+
+/**
+ * Allow client to send refresh registration when the registrar sent a Contact
+ * header with expire parameter 0 in the 200/OK REGISTER response.
+ * Refer to https://github.com/pjsip/pjproject/pull/2809 for more info.
+ *
+ * Default is 1.
+ */
+#ifndef PJSIP_REGISTER_ALLOW_EXP_REFRESH
+#   define PJSIP_REGISTER_ALLOW_EXP_REFRESH	1
+#endif
+
+
 /**
  * Maximum size of pool allowed for auth client session in pjsip_regc.
  * After the size exceeds because of Digest authentication processing,
@@ -1190,6 +1266,20 @@ PJ_INLINE(pjsip_cfg_t*) pjsip_cfg(void)
 #   define PJSIP_AUTH_CACHED_POOL_MAX_SIZE	(20 * 1024)
 #endif
 
+
+/**
+ * Specify whether the cnonce used for SIP authentication contain digits only.
+ * The "cnonce" value is setup using GUID generator, i.e:
+ * pj_create_unique_string(), and the GUID string may contain hyphen character
+ * ("-"). Some SIP servers do not like this GUID format, so this option will
+ * strip any hyphens from the GUID string.
+ *
+ * Default is 1 (cnonce will not contain any hyphen characters).
+ */
+#ifndef PJSIP_AUTH_CNONCE_USE_DIGITS_ONLY
+#   define PJSIP_AUTH_CNONCE_USE_DIGITS_ONLY	1
+#endif
+
 /*****************************************************************************
  *  SIP Event framework and presence settings.
  */
